DateTimeFormatter class

Constructors

DateTimeFormatter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

formatDateTime(int value, String format, DateTimePickerLocale? locale, dynamic weekday) → String
Format datetime string
generateDateFormat(String dateFormat, DateTimePickerMode pickerMode) → String
Get default value of date format.
isDayFormat(String format) → bool
Check if the date format is for day(contain y、M、d、E) or not.
isTimeFormat(String format) → bool
Check if the date format is for time(contain H、m、s) or not.
splitDateFormat(String? dateFormat, {DateTimePickerMode? mode}) → List<String>
Split date format to array.